@@ -27,11 +27,11 @@ class DlgMmsSettings : public KCModule
 {
     Q_OBJECT
     public:
-        explicit DlgMmsSettings(QWidget * parent = 0, const QVariantList &args = QVariantList());
+        explicit DlgMmsSettings(QWidget * parent = nullptr, const QVariantList &args = QVariantList());
 
     public slots:
-        virtual void save();
-        virtual void load();
+        void save() override;
+        void load() override;
 
     private:
         Ui::DlgMms ui;
